Index: virsh.1
===================================================================
RCS file: /data/cvs/libvirt/virsh.1,v
retrieving revision 1.11
diff -u -r1.11 virsh.1
--- virsh.1	5 Feb 2008 19:27:37 -0000	1.11
+++ virsh.1	14 Mar 2008 10:06:33 -0000
@@ -241,7 +241,7 @@
 for each kind of guest which can be virtualized. For a more complete
 description see:
   <http://libvirt.org/format.html#Capa1>
-The \s-1XML\s0 also show the \s-1NUMA\s0 topology informations if available.
+The \s-1XML\s0 also show the \s-1NUMA\s0 topology information if available.
 .IP "\fBlist\fR" 4
 .IX Item "list"
 Prints information about one or more domains.  If no domains are
@@ -353,7 +353,7 @@
 Returns state about a running domain.
 .IP "\fBdumpxml\fR \fIdomain-id\fR" 4
 .IX Item "dumpxml domain-id"
-Output the domain informations as an \s-1XML\s0 dump to stdout, this format can be used by the \fBcreate\fR command.
+Output the domain information as an \s-1XML\s0 dump to stdout, this format can be used by the \fBcreate\fR command.
 .IP "\fBreboot\fR \fIdomain-id\fR" 4
 .IX Item "reboot domain-id"
 Reboot a domain.  This acts just as if the domain had the \fBreboot\fR
@@ -480,7 +480,7 @@
 .IX Header "VIRTUAL NETWORKS COMMANDS"
 The following commands manipulate networks. Libvirt has the capability to
 define virtual networks which can then be used by domains and linked to
-actual network devices. For more detailed informations about this feature
+actual network devices. For more detailed information about this feature
 see the documentation at <http://libvirt.org/format.html#Net1> . A lot
 of the command for virtual networks are similar to the one used for domains,
 but the way to name a virtual network is either by its name or \s-1UUID\s0.
Index: docs/apibuild.py
===================================================================
RCS file: /data/cvs/libvirt/docs/apibuild.py,v
retrieving revision 1.23
diff -u -r1.23 apibuild.py
--- docs/apibuild.py	5 Feb 2008 19:27:37 -0000	1.23
+++ docs/apibuild.py	14 Mar 2008 10:06:33 -0000
@@ -752,7 +752,7 @@
 	return((args, desc))
 
      #
-     # Parse a comment block and merge the informations found in the
+     # Parse a comment block and merge the information found in the
      # parameters descriptions, finally returns a block as complete
      # as possible
      #
Index: docs/architecture.html
===================================================================
RCS file: /data/cvs/libvirt/docs/architecture.html,v
retrieving revision 1.41
diff -u -r1.41 architecture.html
--- docs/architecture.html	20 Feb 2008 15:58:06 -0000	1.41
+++ docs/architecture.html	14 Mar 2008 10:06:34 -0000
@@ -8,7 +8,7 @@
 </ul><h3><a name="Xen" id="Xen">Libvirt Xen support</a></h3><p>When running in a Xen environment, programs using libvirt have to execute
 in "Domain 0", which is the primary Linux OS loaded on the machine. That OS
 kernel provides most if not all of the actual drivers used by the set of
-domains. It also runs the Xen Store, a database of informations shared by the
+domains. It also runs the Xen Store, a database of information shared by the
 hypervisor, the kernels, the drivers and the xen daemon. Xend. The xen daemon
 supervise the control and execution of the sets of domains. The hypervisor,
 drivers, kernels and daemons communicate though a shared system bus
@@ -23,7 +23,7 @@
       as root and providing read-only support</li>
 </ul><p>The library will usually interact with the Xen daemon for any operation
 changing the state of the system, but for performance and accuracy reasons
-may talk directly to the hypervisor when gathering state informations at
+may talk directly to the hypervisor when gathering state information at
 least when possible (i.e. when the running program using libvirt has root
 priviledge access).</p><p>If it runs without root access virConnectOpenReadOnly() should be used to
 connect to initialize the library. It will then fork a libvirt_proxy
Index: docs/errors.html
===================================================================
RCS file: /data/cvs/libvirt/docs/errors.html,v
retrieving revision 1.24
diff -u -r1.24 errors.html
--- docs/errors.html	3 Mar 2008 14:42:37 -0000	1.24
+++ docs/errors.html	14 Mar 2008 10:06:34 -0000
@@ -1,7 +1,7 @@
 <?xml version="1.0" encoding="ISO-8859-1"?>
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" /><link rel="stylesheet" type="text/css" href="libvirt.css" /><link rel="SHORTCUT ICON" href="/32favicon.png" /><title>Handling of errors</title></head><body><div id="container"><div id="intro"><div id="adjustments"></div><div id="pageHeader"></div><div id="content2"><h1 class="style1">Handling of errors</h1><p>The main goals of libvirt when it comes to error handling are:</p><ul><li>provide as much detail as possible</li>
-  <li>provide the informations as soon as possible</li>
+  <li>provide the information as soon as possible</li>
   <li>dont force the library user into one style of error handling</li>
 </ul><p>As result the library provide both synchronous, callback based and
 asynchronous error reporting. When an error happens in the library code the
@@ -15,7 +15,7 @@
 set specifically to a connection with</p><p>So error handling in the code is the following:</p><ol><li>if the error can be associated to a connection for example when failing
     to look up a domain
     <ol><li>if there is a callback associated to the connection set with <a href="html/libvirt-virterror.html#virConnSetErrorFunc">virConnSetErrorFunc</a>,
-        call it with the error informations</li>
+        call it with the error information</li>
       <li>otherwise if there is a global callback set with <a href="html/libvirt-virterror.html#virSetErrorFunc">virSetErrorFunc</a>,
         call it with the error information</li>
       <li>otherwise call <a href="html/libvirt-virterror.html#virDefaultErrorFunc">virDefaultErrorFunc</a>
@@ -31,7 +31,7 @@
         on stderr</li>
       <li>save the error in the connection for later retrieval with <a href="html/libvirt-virterror.html#virGetLastError">virGetLastError</a></li>
     </ol></li>
-</ol><p>In all cases the error informations are provided as a <a href="html/libvirt-virterror.html#virErrorPtr">virErrorPtr</a> pointer to
+</ol><p>In all cases the error information is provided as a <a href="html/libvirt-virterror.html#virErrorPtr">virErrorPtr</a> pointer to
 read-only structure <a href="html/libvirt-virterror.html#virError">virError</a> containing the
 following fields:</p><ul><li>code: an error number from the <a href="html/libvirt-virterror.html#virErrorNumber">virErrorNumber</a>
   enum</li>
@@ -44,10 +44,10 @@
     connection to the hypervisor where this happened</li>
   <li>dom: if available a pointer to the <a href="html/libvirt-libvirt.html#virDomainPtr">virDomainPtr</a> domain
     targetted in the operation</li>
-</ul><p>and then extra raw informations about the error which may be initialized
-to 0 or NULL if unused</p><ul><li>str1, str2, str3: string informations, usually str1 is the error
+</ul><p>and then extra raw information about the error which may be initialized
+to 0 or NULL if unused</p><ul><li>str1, str2, str3: string information, usually str1 is the error
     message format</li>
-  <li>int1, int2: integer informations</li>
+  <li>int1, int2: integer information</li>
 </ul><p>So usually, setting up specific error handling with libvirt consist of
 registering an handler with with <a href="html/libvirt-virterror.html#virSetErrorFunc">virSetErrorFunc</a> or
 with <a href="html/libvirt-virterror.html#virConnSetErrorFunc">virConnSetErrorFunc</a>,
Index: docs/format.html
===================================================================
RCS file: /data/cvs/libvirt/docs/format.html,v
retrieving revision 1.37
diff -u -r1.37 format.html
--- docs/format.html	3 Mar 2008 14:42:37 -0000	1.37
+++ docs/format.html	14 Mar 2008 10:06:34 -0000
@@ -157,7 +157,7 @@
   <li>the <code>&lt;os&gt;</code> block description is very different, first
     it indicates that the type is 'hvm' for hardware virtualization, then
     instead of a kernel, boot and command line arguments, it points to an os
-    boot loader which will extract the boot informations from the boot device
+    boot loader which will extract the boot information from the boot device
     specified in a separate boot element. The <code>dev</code> attribute on
     the <code>boot</code> tag can be one of:
     <ul><li><code>fd</code> - boot from first floppy device</li>
@@ -415,7 +415,7 @@
 block is similar to what you will find in a Xen fully virtualized domain
 description).</p><p>The second block (in blue) indicates the paravirtualization support of the
 Xen support, you will see the os_type of xen to indicate a paravirtual
-kernel, then architecture informations and potential features.</p><p>The third block (in green) gives similar informations but when running a
+kernel, then architecture information and potential features.</p><p>The third block (in green) gives similar information but when running a
 32 bit OS fully virtualized with Xen using the hvm support.</p><p>This section is likely to be updated and augmented in the future, see <a href="https://www.redhat.com/archives/libvir-list/2007-March/msg00215.html">the
 discussion</a> which led to the capabilities format in the mailing-list
 archives.</p></div></div><div class="linkList2"><div class="llinks2"><h3 class="links2"><span>main menu</span></h3><ul><li><a href="index.html">Home</a></li><li><a href="news.html">Releases</a></li><li><a href="intro.html">Introduction</a></li><li><a href="architecture.html">libvirt architecture</a></li><li><a href="downloads.html">Downloads</a></li><li><a href="format.html">XML Format</a></li><li><a href="python.html">Bindings for other languages</a></li><li><a href="errors.html">Handling of errors</a></li><li><a href="FAQ.html">FAQ</a></li><li><a href="bugs.html">Reporting bugs and getting help</a></li><li><a href="windows.html">Windows support</a></li><li><a href="remote.html">Remote support</a></li><li><a href="auth.html">Access control</a></li><li><a href="uri.html">Connection URIs</a></li><li><a href="hvsupport.html">Hypervisor support</a></li><li><a href="storage.html">Storage Management</a></li><li><a href="html/index.html">API Menu</a></li><li><a href="examples/index.html">C code examples</a></li><li><a href="ChangeLog.html">Recent Changes</a></li></ul></div><div class="llinks2"><h3 class="links2"><span>related links</span></h3><ul><li><a href="https://www.redhat.com/archives/libvir-list/">Mail archive</a></li><li><a href="https://bugzilla.redhat.com/bugzilla/buglist.cgi?product=Fedora+Core&amp;component=libvirt&amp;bug_status=NEW&amp;bug_status=ASSIGNED&amp;bug_status=REOPENED&amp;bug_status=MODIFIED&amp;short_desc_type=allwordssubstr&amp;short_desc=&amp;long_desc_type=allwordssubstr">Open bugs</a></li><li><a href="http://virt-manager.et.redhat.com/">virt-manager</a></li><li><a href="http://search.cpan.org/~danberr/Sys-Virt-0.1.0/">Perl bindings</a></li><li><a href="http://libvirt.org/ocaml/">OCaml bindings</a></li><li><a href="http://libvirt.org/ruby/">Ruby bindings</a></li><li><a href="http://www.cl.cam.ac.uk/Research/SRG/netos/xen/index.html">Xen project</a></li><li><form action="search.php" enctype="application/x-www-form-urlencoded" method="get"><input name="query" type="text" size="12" value="Search..." /><input name="submit" type="submit" value="Go" /></form></li><li><a href="http://xmlsoft.org/"><img src="Libxml2-Logo-90x34.gif" alt="Made with Libxml2 Logo" /></a></li></ul><p class="credits">Graphics and design by <a href="mail:dfong@redhat.com">Diana Fong</a></p></div></div><div id="bottom"><p class="p1"></p></div></div></body></html>
Index: docs/index.py
===================================================================
RCS file: /data/cvs/libvirt/docs/index.py,v
retrieving revision 1.3
diff -u -r1.3 index.py
--- docs/index.py	5 Feb 2008 19:27:37 -0000	1.3
+++ docs/index.py	14 Mar 2008 10:06:35 -0000
@@ -34,7 +34,7 @@
 #    Bye
 #
 # Then run the script in the doc subdir, it will create the symbols and
-# word tables and populate them with informations extracted from
+# word tables and populate them with information extracted from
 # the libvirt-api.xml API description, and make then accessible read-only
 # by nobody@loaclhost the user expected to be Apache's one
 #
Index: docs/libvir.html
===================================================================
RCS file: /data/cvs/libvirt/docs/libvir.html,v
retrieving revision 1.110
diff -u -r1.110 libvir.html
--- docs/libvir.html	7 Mar 2008 11:13:02 -0000	1.110
+++ docs/libvir.html	14 Mar 2008 10:06:41 -0000
@@ -254,7 +254,7 @@
   <li>Documentation: remote support (Richard Jones), description of
       the URI connection strings (Richard Jones), update of virsh man
       page, matrix of libvirt API/hypervisor support with version
-      informations (Richard Jones)</li>
+      information (Richard Jones)</li>
   <li>Bug fixes: examples Makefile.am generation (Richard Jones),
       SetMem fix (Mark Johnson), URI handling and ordering of
       drivers (Daniel Berrange), fix virsh help without hypervisor (Richard
@@ -424,7 +424,7 @@
 <h3>0.1.9: Nov 29 2006</h3>
 <ul>
   <li>python bindings: release interpeter lock when calling C (Daniel Berrange)</li>
-  <li>don't raise HTTP error when looking informations for a domain</li>
+  <li>don't raise HTTP error when looking information for a domain</li>
   <li>some refactoring to use the driver for all entry points</li>
   <li>better error reporting (Daniel Berrange)</li>
   <li>fix OS reporting when running as non-root</li>
@@ -442,7 +442,7 @@
   <li>added support for inactive domains, new APIs, various associated cleanup (Daniel Berrange)</li>
   <li>special device model for HVM guests (Daniel Berrange)</li>
   <li>add API to dump core of domains (but requires a patched xend)</li>
-  <li>pygrub bootloader informations take over &lt;os&gt; informations</li>
+  <li>pygrub bootloader information take over &lt;os&gt; information</li>
   <li>updated the localization strings</li>
 </ul>
 <h3>0.1.8: Oct 16 2006</h3>
@@ -459,9 +459,9 @@
 </ul>
 <h3>0.1.7: Sep 29 2006</h3>
 <ul>
-  <li> fix a memory bug on getting vcpu informations from xend (Daniel Berrange)</li>
+  <li> fix a memory bug on getting vcpu information from xend (Daniel Berrange)</li>
   <li> fix another problem in the hypercalls change in Xen changeset
-       86d26e6ec89b when getting domain informations (Daniel Berrange)</li>
+       86d26e6ec89b when getting domain information (Daniel Berrange)</li>
 </ul>
 <h3>0.1.6: Sep 22 2006</h3>
 <ul>
@@ -497,7 +497,7 @@
     initialization errors (Daniel Berrange)</li>
   <li>improvements: UUID in XML description (Peter Vetere), proxy code
     cleanup, virtual CPU and affinity support + virsh support (Michel
-    Ponceau, Philippe Berthault, Daniel Berrange), port and tty informations
+    Ponceau, Philippe Berthault, Daniel Berrange), port and tty information
     for console in XML (Daniel Berrange), added XML dump to driver and proxy
     support (Daniel Berrange), extention of boot options with support for
     floppy and cdrom (Daniel Berrange), features block in XML to report/ask
@@ -678,7 +678,7 @@
 <p>When running in a Xen environment, programs using libvirt have to execute
 in "Domain 0", which is the primary Linux OS loaded on the machine. That OS
 kernel provides most if not all of the actual drivers used by the set of
-domains. It also runs the Xen Store, a database of informations shared by the
+domains. It also runs the Xen Store, a database of information shared by the
 hypervisor, the kernels, the drivers and the xen daemon. Xend. The xen daemon
 supervise the control and execution of the sets of domains. The hypervisor,
 drivers, kernels and daemons communicate though a shared system bus
@@ -700,7 +700,7 @@
 
 <p>The library will usually interact with the Xen daemon for any operation
 changing the state of the system, but for performance and accuracy reasons
-may talk directly to the hypervisor when gathering state informations at
+may talk directly to the hypervisor when gathering state information at
 least when possible (i.e. when the running program using libvirt has root
 priviledge access).</p>
 
@@ -995,7 +995,7 @@
   <li>the <code>&lt;os&gt;</code> block description is very different, first
     it indicates that the type is 'hvm' for hardware virtualization, then
     instead of a kernel, boot and command line arguments, it points to an os
-    boot loader which will extract the boot informations from the boot device
+    boot loader which will extract the boot information from the boot device
     specified in a separate boot element. The <code>dev</code> attribute on
     the <code>boot</code> tag can be one of:
     <ul>
@@ -1300,9 +1300,9 @@
 
 <p>The second block (in blue) indicates the paravirtualization support of the
 Xen support, you will see the os_type of xen to indicate a paravirtual
-kernel, then architecture informations and potential features.</p>
+kernel, then architecture information and potential features.</p>
 
-<p>The third block (in green) gives similar informations but when running a
+<p>The third block (in green) gives similar information but when running a
 32 bit OS fully virtualized with Xen using the hvm support.</p>
 
 <p>This section is likely to be updated and augmented in the future, see <a
@@ -1319,7 +1319,7 @@
 <ul>
   <li>Python: Libvirt comes with direct support for the Python language
      (just make sure you installed the libvirt-python package if not
-     compiling from sources). See below for more informations about
+     compiling from sources). See below for more information about
      using libvirt with python</li>
   <li>Perl: Daniel Berrange provides <a
      href="http://search.cpan.org/~danberr/Sys-Virt-0.1.0/">bindings for
@@ -1332,7 +1332,7 @@
 
 <p>Support, requests or help for libvirt bindings are welcome on
 the <a href="https://www.redhat.com/mailman/listinfo/libvir-list/">mailing
-list</a>, as usual try to provide enough background informations
+list</a>, as usual try to provide enough background information
 and make sure you use recent version, see the <a href="bugs.html">help
 page</a>.</p>
 
@@ -1411,7 +1411,7 @@
   <li>getting an object representing the Domain 0 using <span
     style="color: #007F00; background-color: #FFFFFF">lookupByName</span></li>
   <li>if the domain is not found a libvirtError exception will be raised</li>
-  <li>extracting and printing some informations about the domain using
+  <li>extracting and printing some information about the domain using
     various <span
     style="color: #E50073; background-color: #FFFFFF">methods</span>
     associated to the virDomain class.</li>
@@ -1422,7 +1422,7 @@
 <p>The main goals of libvirt when it comes to error handling are:</p>
 <ul>
   <li>provide as much detail as possible</li>
-  <li>provide the informations as soon as possible</li>
+  <li>provide the information as soon as possible</li>
   <li>dont force the library user into one style of error handling</li>
 </ul>
 
@@ -1446,7 +1446,7 @@
     <ol>
       <li>if there is a callback associated to the connection set with <a
         href="html/libvirt-virterror.html#virConnSetErrorFunc">virConnSetErrorFunc</a>,
-        call it with the error informations</li>
+        call it with the error information</li>
       <li>otherwise if there is a global callback set with <a
         href="html/libvirt-virterror.html#virSetErrorFunc">virSetErrorFunc</a>,
         call it with the error information</li>
@@ -1473,7 +1473,7 @@
   </li>
 </ol>
 
-<p>In all cases the error informations are provided as a <a
+<p>In all cases the error information is provided as a <a
 href="html/libvirt-virterror.html#virErrorPtr">virErrorPtr</a> pointer to
 read-only structure <a
 href="html/libvirt-virterror.html#virError">virError</a> containing the
@@ -1496,12 +1496,12 @@
     targetted in the operation</li>
 </ul>
 
-<p>and then extra raw informations about the error which may be initialized
+<p>and then extra raw information about the error which may be initialized
 to 0 or NULL if unused</p>
 <ul>
-  <li>str1, str2, str3: string informations, usually str1 is the error
+  <li>str1, str2, str3: string information, usually str1 is the error
     message format</li>
-  <li>int1, int2: integer informations</li>
+  <li>int1, int2: integer information</li>
 </ul>
 
 <p>So usually, setting up specific error handling with libvirt consist of
Index: docs/libvirt-api.xml
===================================================================
RCS file: /data/cvs/libvirt/docs/libvirt-api.xml,v
retrieving revision 1.44
diff -u -r1.44 libvirt-api.xml
--- docs/libvirt-api.xml	3 Mar 2008 06:18:06 -0000	1.44
+++ docs/libvirt-api.xml	14 Mar 2008 10:06:46 -0000
@@ -406,8 +406,8 @@
     <enum name='VIR_DOMAIN_SCHED_FIELD_ULLONG' file='libvirt' value='4' type='virSchedParameterType' info='unsigned long long case'/>
     <enum name='VIR_DOMAIN_SHUTDOWN' file='libvirt' value='4' type='virDomainState' info='the domain is being shut down'/>
     <enum name='VIR_DOMAIN_SHUTOFF' file='libvirt' value='5' type='virDomainState' info='the domain is shut off'/>
-    <enum name='VIR_DOMAIN_XML_INACTIVE' file='libvirt' value='2' type='virDomainXMLFlags' info=' dump inactive domain informations'/>
-    <enum name='VIR_DOMAIN_XML_SECURE' file='libvirt' value='1' type='virDomainXMLFlags' info='dump security sensitive informations too'/>
+    <enum name='VIR_DOMAIN_XML_INACTIVE' file='libvirt' value='2' type='virDomainXMLFlags' info=' dump inactive domain information'/>
+    <enum name='VIR_DOMAIN_XML_SECURE' file='libvirt' value='1' type='virDomainXMLFlags' info='dump security sensitive information too'/>
     <enum name='VIR_ERR_AUTH_FAILED' file='virterror' value='45' type='virErrorNumber' info='authentication failed'/>
     <enum name='VIR_ERR_CALL_FAILED' file='virterror' value='26' type='virErrorNumber' info='not supported by the drivers (DEPRECATED)'/>
     <enum name='VIR_ERR_CONF_SYNTAX' file='virterror' value='33' type='virErrorNumber' info='failed to parse the syntax of a conf file'/>
Index: docs/libvirt.rng
===================================================================
RCS file: /data/cvs/libvirt/docs/libvirt.rng,v
retrieving revision 1.6
diff -u -r1.6 libvirt.rng
--- docs/libvirt.rng	5 Feb 2008 19:27:37 -0000	1.6
+++ docs/libvirt.rng	14 Mar 2008 10:06:47 -0000
@@ -25,8 +25,8 @@
 
   <!--
       Description of a Xen domain:
-      The description must start with the identification informations and then
-      os or bootloader, resources, features, devices and termination informations
+      The description must start with the identification information and then
+      os or bootloader, resources, features, devices and termination information
       can be given in any order.
     -->
   <define name='xen-domain'>
@@ -60,7 +60,7 @@
 
   <!--
       Description of a QEmu domain:
-      The description must start with the identification informations and then
+      The description must start with the identification information and then
       os, resources, devices can be given in any order.
       The specific part are the combinations of architectures and machines
       being emulated.
@@ -145,7 +145,7 @@
 
   <!--
       Description of a KVM domain:
-      The description must start with the identification informations and then
+      The description must start with the identification information and then
       os, resources, devices can be given in any order.
     -->
   <define name='kvm-domain'>
Index: docs/news.html
===================================================================
RCS file: /data/cvs/libvirt/docs/news.html,v
retrieving revision 1.66
diff -u -r1.66 news.html
--- docs/news.html	3 Mar 2008 14:42:37 -0000	1.66
+++ docs/news.html	14 Mar 2008 10:06:48 -0000
@@ -199,7 +199,7 @@
   </li><li>Documentation: remote support (Richard Jones), description of
       the URI connection strings (Richard Jones), update of virsh man
       page, matrix of libvirt API/hypervisor support with version
-      informations (Richard Jones)</li>
+      information (Richard Jones)</li>
   <li>Bug fixes: examples Makefile.am generation (Richard Jones),
       SetMem fix (Mark Johnson), URI handling and ordering of
       drivers (Daniel Berrange), fix virsh help without hypervisor (Richard
@@ -344,7 +344,7 @@
   <li>bug fixes: VCPU info breakages on xen 3.0.3, xenDaemonListDomains buffer overflow (Daniel Berrange), reference count bug when creating Xen domains (Daniel Berrange).</li>
   <li>improvements: support graphic framebuffer for Xen paravirt (Daniel Berrange), VNC listen IP range support (Daniel Berrange), support for default Xen config files and inactive domains of 3.0.4 (Daniel Berrange).</li>
 </ul><h3>0.1.9: Nov 29 2006</h3><ul><li>python bindings: release interpeter lock when calling C (Daniel Berrange)</li>
-  <li>don't raise HTTP error when looking informations for a domain</li>
+  <li>don't raise HTTP error when looking information for a domain</li>
   <li>some refactoring to use the driver for all entry points</li>
   <li>better error reporting (Daniel Berrange)</li>
   <li>fix OS reporting when running as non-root</li>
@@ -362,7 +362,7 @@
   <li>added support for inactive domains, new APIs, various associated cleanup (Daniel Berrange)</li>
   <li>special device model for HVM guests (Daniel Berrange)</li>
   <li>add API to dump core of domains (but requires a patched xend)</li>
-  <li>pygrub bootloader informations take over &lt;os&gt; informations</li>
+  <li>pygrub bootloader information take over &lt;os&gt; information</li>
   <li>updated the localization strings</li>
 </ul><h3>0.1.8: Oct 16 2006</h3><ul><li> Bug for system with page size != 4k</li>
   <li> vcpu number initialization (Philippe Berthault)</li>
@@ -373,9 +373,9 @@
   <li> compile fix</li>
   <li> mlock/munlock size fixes (Daniel Berrange)</li>
   <li> improve error reporting</li>
-</ul><h3>0.1.7: Sep 29 2006</h3><ul><li> fix a memory bug on getting vcpu informations from xend (Daniel Berrange)</li>
+</ul><h3>0.1.7: Sep 29 2006</h3><ul><li> fix a memory bug on getting vcpu information from xend (Daniel Berrange)</li>
   <li> fix another problem in the hypercalls change in Xen changeset
-       86d26e6ec89b when getting domain informations (Daniel Berrange)</li>
+       86d26e6ec89b when getting domain information (Daniel Berrange)</li>
 </ul><h3>0.1.6: Sep 22 2006</h3><ul><li>Support for localization of strings using gettext (Daniel Berrange)</li>
   <li>Support for new Xen-3.0.3 cdrom and disk configuration (Daniel Berrange)</li>
   <li>Support for setting VNC port when creating domains with new
@@ -401,7 +401,7 @@
     initialization errors (Daniel Berrange)</li>
   <li>improvements: UUID in XML description (Peter Vetere), proxy code
     cleanup, virtual CPU and affinity support + virsh support (Michel
-    Ponceau, Philippe Berthault, Daniel Berrange), port and tty informations
+    Ponceau, Philippe Berthault, Daniel Berrange), port and tty information
     for console in XML (Daniel Berrange), added XML dump to driver and proxy
     support (Daniel Berrange), extention of boot options with support for
     floppy and cdrom (Daniel Berrange), features block in XML to report/ask
Index: docs/python.html
===================================================================
RCS file: /data/cvs/libvirt/docs/python.html,v
retrieving revision 1.24
diff -u -r1.24 python.html
--- docs/python.html	3 Mar 2008 14:42:37 -0000	1.24
+++ docs/python.html	14 Mar 2008 10:06:49 -0000
@@ -5,7 +5,7 @@
 allow direct acces from C++ code, but also we have bindings for
 higher level kind of languages:</p><ul><li>Python: Libvirt comes with direct support for the Python language
      (just make sure you installed the libvirt-python package if not
-     compiling from sources). See below for more informations about
+     compiling from sources). See below for more information about
      using libvirt with python</li>
   <li>Perl: Daniel Berrange provides <a href="http://search.cpan.org/~danberr/Sys-Virt-0.1.0/">bindings for
      Perl</a>.</li>
@@ -13,7 +13,7 @@
   <li>Ruby: David Lutterkork provides <a href="http://libvirt.org/ruby/">bindings for Ruby</a>.</li>
 </ul><p>Support, requests or help for libvirt bindings are welcome on
 the <a href="https://www.redhat.com/mailman/listinfo/libvir-list/">mailing
-list</a>, as usual try to provide enough background informations
+list</a>, as usual try to provide enough background information
 and make sure you use recent version, see the <a href="bugs.html">help
 page</a>.</p><p>The remaining of this page focuses on the Python bindings.</p><p>The Python binding should be complete and are mostly automatically
 generated from the formal description of the API in xml. The bindings are
@@ -59,7 +59,7 @@
     openReadOnly function allows the code to execute as a normal user.</li>
   <li>getting an object representing the Domain 0 using <span style="color: #007F00; background-color: #FFFFFF">lookupByName</span></li>
   <li>if the domain is not found a libvirtError exception will be raised</li>
-  <li>extracting and printing some informations about the domain using
+  <li>extracting and printing some information about the domain using
     various <span style="color: #E50073; background-color: #FFFFFF">methods</span>
     associated to the virDomain class.</li>
 </ul></div></div><div class="linkList2"><div class="llinks2"><h3 class="links2"><span>main menu</span></h3><ul><li><a href="index.html">Home</a></li><li><a href="news.html">Releases</a></li><li><a href="intro.html">Introduction</a></li><li><a href="architecture.html">libvirt architecture</a></li><li><a href="downloads.html">Downloads</a></li><li><a href="format.html">XML Format</a></li><li><a href="python.html">Bindings for other languages</a></li><li><a href="errors.html">Handling of errors</a></li><li><a href="FAQ.html">FAQ</a></li><li><a href="bugs.html">Reporting bugs and getting help</a></li><li><a href="windows.html">Windows support</a></li><li><a href="remote.html">Remote support</a></li><li><a href="auth.html">Access control</a></li><li><a href="uri.html">Connection URIs</a></li><li><a href="hvsupport.html">Hypervisor support</a></li><li><a href="storage.html">Storage Management</a></li><li><a href="html/index.html">API Menu</a></li><li><a href="examples/index.html">C code examples</a></li><li><a href="ChangeLog.html">Recent Changes</a></li></ul></div><div class="llinks2"><h3 class="links2"><span>related links</span></h3><ul><li><a href="https://www.redhat.com/archives/libvir-list/">Mail archive</a></li><li><a href="https://bugzilla.redhat.com/bugzilla/buglist.cgi?product=Fedora+Core&amp;component=libvirt&amp;bug_status=NEW&amp;bug_status=ASSIGNED&amp;bug_status=REOPENED&amp;bug_status=MODIFIED&amp;short_desc_type=allwordssubstr&amp;short_desc=&amp;long_desc_type=allwordssubstr">Open bugs</a></li><li><a href="http://virt-manager.et.redhat.com/">virt-manager</a></li><li><a href="http://search.cpan.org/~danberr/Sys-Virt-0.1.0/">Perl bindings</a></li><li><a href="http://libvirt.org/ocaml/">OCaml bindings</a></li><li><a href="http://libvirt.org/ruby/">Ruby bindings</a></li><li><a href="http://www.cl.cam.ac.uk/Research/SRG/netos/xen/index.html">Xen project</a></li><li><form action="search.php" enctype="application/x-www-form-urlencoded" method="get"><input name="query" type="text" size="12" value="Search..." /><input name="submit" type="submit" value="Go" /></form></li><li><a href="http://xmlsoft.org/"><img src="Libxml2-Logo-90x34.gif" alt="Made with Libxml2 Logo" /></a></li></ul><p class="credits">Graphics and design by <a href="mail:dfong@redhat.com">Diana Fong</a></p></div></div><div id="bottom"><p class="p1"></p></div></div></body></html>
Index: docs/virsh.pod
===================================================================
RCS file: /data/cvs/libvirt/docs/virsh.pod,v
retrieving revision 1.11
diff -u -r1.11 virsh.pod
--- docs/virsh.pod	5 Feb 2008 19:27:37 -0000	1.11
+++ docs/virsh.pod	14 Mar 2008 10:06:50 -0000
@@ -121,7 +121,7 @@
 for each kind of guest which can be virtualized. For a more complete
 description see:
   L<http://libvirt.org/format.html#Capa1>
-The XML also show the NUMA topology informations if available.
+The XML also show the NUMA topology information if available.
 
 =item B<list>
 
@@ -255,7 +255,7 @@
 
 =item B<dumpxml> I<domain-id>
 
-Output the domain informations as an XML dump to stdout, this format can be used by the B<create> command.
+Output the domain information as an XML dump to stdout, this format can be used by the B<create> command.
 
 
 =item B<reboot> I<domain-id>
@@ -413,7 +413,7 @@
 
 The following commands manipulate networks. Libvirt has the capability to
 define virtual networks which can then be used by domains and linked to
-actual network devices. For more detailed informations about this feature
+actual network devices. For more detailed information about this feature
 see the documentation at L<http://libvirt.org/format.html#Net1> . A lot
 of the command for virtual networks are similar to the one used for domains,
 but the way to name a virtual network is either by its name or UUID.
Index: docs/devhelp/libvirt-libvirt.html
===================================================================
RCS file: /data/cvs/libvirt/docs/devhelp/libvirt-libvirt.html,v
retrieving revision 1.24
diff -u -r1.24 libvirt-libvirt.html
--- docs/devhelp/libvirt-libvirt.html	3 Mar 2008 06:18:06 -0000	1.24
+++ docs/devhelp/libvirt-libvirt.html	14 Mar 2008 10:06:58 -0000
@@ -404,8 +404,8 @@
 </div>
         <hr/>
         <div class="refsect2" lang="en"><h3><a name="virDomainXMLFlags">Enum </a>virDomainXMLFlags</h3><pre class="programlisting">enum <a href="#virDomainXMLFlags">virDomainXMLFlags</a> {
-    <a name="VIR_DOMAIN_XML_SECURE">VIR_DOMAIN_XML_SECURE</a> = 1 /* dump security sensitive informations too */
-    <a name="VIR_DOMAIN_XML_INACTIVE">VIR_DOMAIN_XML_INACTIVE</a> = 2 /*  dump inactive domain informations */
+    <a name="VIR_DOMAIN_XML_SECURE">VIR_DOMAIN_XML_SECURE</a> = 1 /* dump security sensitive information too */
+    <a name="VIR_DOMAIN_XML_INACTIVE">VIR_DOMAIN_XML_INACTIVE</a> = 2 /*  dump inactive domain information */
 };
 </pre><p/>
 </div>
Index: docs/examples/examples.xml
===================================================================
RCS file: /data/cvs/libvirt/docs/examples/examples.xml,v
retrieving revision 1.9
diff -u -r1.9 examples.xml
--- docs/examples/examples.xml	15 Jan 2008 15:27:31 -0000	1.9
+++ docs/examples/examples.xml	14 Mar 2008 10:06:59 -0000
@@ -1,7 +1,7 @@
 <examples>
   <example filename='info1.c'>
-    <synopsis>Extract informations about Xen domain 0</synopsis>
-    <purpose>Demonstrate the basic use of the library to connect to the hypervisor and extract domain informations.</purpose>
+    <synopsis>Extract information about Xen domain 0</synopsis>
+    <purpose>Demonstrate the basic use of the library to connect to the hypervisor and extract domain information.</purpose>
     <usage>info1</usage>
     <test>info1</test>
     <author>Daniel Veillard</author>
Index: docs/examples/index.html
===================================================================
RCS file: /data/cvs/libvirt/docs/examples/index.html,v
retrieving revision 1.3
diff -u -r1.3 index.html
--- docs/examples/index.html	28 Feb 2008 17:06:32 -0000	1.3
+++ docs/examples/index.html	14 Mar 2008 10:06:59 -0000
@@ -1,7 +1,7 @@
 <?xml version="1.0" encoding="ISO-8859-1"?>
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" /><link rel="stylesheet" type="text/css" href="../libvirt.css" /><link rel="SHORTCUT ICON" href="/32favicon.png" /><title>Libvirt set of C code examples</title></head><body><div id="container"><div id="intro"><div id="adjustments"></div><div id="pageHeader"></div><div id="content2"><h1 class="style1">Libvirt set of C code examples</h1><p> The examples are stored per section depending on the main focus
-    of the example:</p><ul><li><p><a href="#Informations">Informations</a> :</p><ul><li><a href="#info1.c">info1.c</a>: Extract informations about Xen domain 0</li></ul></li><li><p><a href="#Scheduling">Scheduling</a> :</p><ul><li><a href="#suspend.c">suspend.c</a>: Suspend a domain and then resume its execution</li></ul></li></ul><p> Getting the compilation options and libraries dependancies needed
+    of the example:</p><ul><li><p><a href="#Informations">Informations</a> :</p><ul><li><a href="#info1.c">info1.c</a>: Extract information about Xen domain 0</li></ul></li><li><p><a href="#Scheduling">Scheduling</a> :</p><ul><li><a href="#suspend.c">suspend.c</a>: Suspend a domain and then resume its execution</li></ul></li></ul><p> Getting the compilation options and libraries dependancies needed
 to generate binaries from the examples is best done on Linux/Unix by using
 the pkg-config data which should have been installed as part of <i>make
-install</i> step or when installing the libvirt development package:</p><pre>gcc -o example example.c `pkg-config libvirt --libs`</pre><h2><a name="Informations" id="Informations"></a>Informations Examples</h2><h3><a name="info1.c" href="info1.c" id="info1.c">info1.c</a>: Extract informations about Xen domain 0</h3><p>Demonstrate the basic use of the library to connect to the hypervisor and extract domain informations.</p><p>Uses:</p><ul><li> line 29: Function <a href="../html/libvirt-libvirt.html#virConnectOpenReadOnly">virConnectOpenReadOnly</a> from libvirt.h</li><li> line 36: Function <a href="../html/libvirt-libvirt.html#virDomainLookupByID">virDomainLookupByID</a> from libvirt.h</li><li> line 43: Function <a href="../html/libvirt-libvirt.html#virDomainGetInfo">virDomainGetInfo</a> from libvirt.h</li><li> line 53: Function <a href="../html/libvirt-libvirt.html#virDomainFree">virDomainFree</a> from libvirt.h</li><li> line 55: Function <a href="../html/libvirt-libvirt.html#virConnectClose">virConnectClose</a> from libvirt.h</li></ul><p>Usage:</p><p>info1</p><p>Author: Daniel Veillard</p><h2><a name="Scheduling" id="Scheduling"></a>Scheduling Examples</h2><h3><a name="suspend.c" href="suspend.c" id="suspend.c">suspend.c</a>: Suspend a domain and then resume its execution</h3><p>Demonstrate the basic use of the library to suspend and resume a domain. If no id is given on the command line this script will suspend and resume the first domain found which is not Domain 0.</p><p>Uses:</p><ul><li> line 31: Function <a href="../html/libvirt-libvirt.html#virDomainGetInfo">virDomainGetInfo</a> from libvirt.h</li><li> line 50: Function <a href="../html/libvirt-libvirt.html#virDomainLookupByID">virDomainLookupByID</a> from libvirt.h</li><li> line 62: Function <a href="../html/libvirt-libvirt.html#virDomainSuspend">virDomainSuspend</a> from libvirt.h</li><li> line 73: Function <a href="../html/libvirt-libvirt.html#virDomainResume">virDomainResume</a> from libvirt.h</li><li> line 93: Function <a href="../html/libvirt-libvirt.html#virDomainFree">virDomainFree</a> from libvirt.h</li><li> line 100: Function <a href="../html/libvirt-libvirt.html#virConnectOpenReadOnly">virConnectOpenReadOnly</a> from libvirt.h</li><li> line 111: Function <a href="../html/libvirt-libvirt.html#virConnectListDomains">virConnectListDomains</a> from libvirt.h</li><li> line 132: Function <a href="../html/libvirt-libvirt.html#virConnectClose">virConnectClose</a> from libvirt.h</li></ul><p>Usage:</p><p>suspend [id]</p><p>Author: Daniel Veillard</p></div></div><div class="linkList2"><div class="llinks2"><h3 class="links2"><span>main menu</span></h3><ul><li><a href="../index.html">Home</a></li><li><a href="../html/index.html">API Menu</a></li><li><a href="../examples/index.html">C code examples</a></li><li><a href="../ChangeLog.html">Recent Changes</a></li></ul></div><div class="llinks2"><h3 class="links2"><span>related links</span></h3><ul><li><a href="https://www.redhat.com/archives/libvir-list/">Mail archive</a></li><li><a href="https://bugzilla.redhat.com/bugzilla/buglist.cgi?product=Fedora+Core&amp;component=libvirt&amp;bug_status=NEW&amp;bug_status=ASSIGNED&amp;bug_status=REOPENED&amp;bug_status=MODIFIED&amp;short_desc_type=allwordssubstr&amp;short_desc=&amp;long_desc_type=allwordssubstr">Open bugs</a></li><li><a href="http://virt-manager.et.redhat.com/">virt-manager</a></li><li><a href="http://search.cpan.org/~danberr/Sys-Virt-0.1.0/">Perl bindings</a></li><li><a href="http://libvirt.org/ocaml/">OCaml bindings</a></li><li><a href="http://libvirt.org/ruby/">Ruby bindings</a></li><li><a href="http://www.cl.cam.ac.uk/Research/SRG/netos/xen/index.html">Xen project</a></li><li><form action="../search.php" enctype="application/x-www-form-urlencoded" method="get"><input name="query" type="text" size="12" value="Search..." /><input name="submit" type="submit" value="Go" /></form></li><li><a href="http://xmlsoft.org/"><img src="../Libxml2-Logo-90x34.gif" alt="Made with Libxml2 Logo" /></a></li></ul><p class="credits">Graphics and design by <a href="mail:dfong@redhat.com">Diana Fong</a></p></div></div><div id="bottom"><p class="p1"></p></div></div></body></html>
+install</i> step or when installing the libvirt development package:</p><pre>gcc -o example example.c `pkg-config libvirt --libs`</pre><h2><a name="Informations" id="Informations"></a>Informations Examples</h2><h3><a name="info1.c" href="info1.c" id="info1.c">info1.c</a>: Extract information about Xen domain 0</h3><p>Demonstrate the basic use of the library to connect to the hypervisor and extract domain information.</p><p>Uses:</p><ul><li> line 29: Function <a href="../html/libvirt-libvirt.html#virConnectOpenReadOnly">virConnectOpenReadOnly</a> from libvirt.h</li><li> line 36: Function <a href="../html/libvirt-libvirt.html#virDomainLookupByID">virDomainLookupByID</a> from libvirt.h</li><li> line 43: Function <a href="../html/libvirt-libvirt.html#virDomainGetInfo">virDomainGetInfo</a> from libvirt.h</li><li> line 53: Function <a href="../html/libvirt-libvirt.html#virDomainFree">virDomainFree</a> from libvirt.h</li><li> line 55: Function <a href="../html/libvirt-libvirt.html#virConnectClose">virConnectClose</a> from libvirt.h</li></ul><p>Usage:</p><p>info1</p><p>Author: Daniel Veillard</p><h2><a name="Scheduling" id="Scheduling"></a>Scheduling Examples</h2><h3><a name="suspend.c" href="suspend.c" id="suspend.c">suspend.c</a>: Suspend a domain and then resume its execution</h3><p>Demonstrate the basic use of the library to suspend and resume a domain. If no id is given on the command line this script will suspend and resume the first domain found which is not Domain 0.</p><p>Uses:</p><ul><li> line 31: Function <a href="../html/libvirt-libvirt.html#virDomainGetInfo">virDomainGetInfo</a> from libvirt.h</li><li> line 50: Function <a href="../html/libvirt-libvirt.html#virDomainLookupByID">virDomainLookupByID</a> from libvirt.h</li><li> line 62: Function <a href="../html/libvirt-libvirt.html#virDomainSuspend">virDomainSuspend</a> from libvirt.h</li><li> line 73: Function <a href="../html/libvirt-libvirt.html#virDomainResume">virDomainResume</a> from libvirt.h</li><li> line 93: Function <a href="../html/libvirt-libvirt.html#virDomainFree">virDomainFree</a> from libvirt.h</li><li> line 100: Function <a href="../html/libvirt-libvirt.html#virConnectOpenReadOnly">virConnectOpenReadOnly</a> from libvirt.h</li><li> line 111: Function <a href="../html/libvirt-libvirt.html#virConnectListDomains">virConnectListDomains</a> from libvirt.h</li><li> line 132: Function <a href="../html/libvirt-libvirt.html#virConnectClose">virConnectClose</a> from libvirt.h</li></ul><p>Usage:</p><p>suspend [id]</p><p>Author: Daniel Veillard</p></div></div><div class="linkList2"><div class="llinks2"><h3 class="links2"><span>main menu</span></h3><ul><li><a href="../index.html">Home</a></li><li><a href="../html/index.html">API Menu</a></li><li><a href="../examples/index.html">C code examples</a></li><li><a href="../ChangeLog.html">Recent Changes</a></li></ul></div><div class="llinks2"><h3 class="links2"><span>related links</span></h3><ul><li><a href="https://www.redhat.com/archives/libvir-list/">Mail archive</a></li><li><a href="https://bugzilla.redhat.com/bugzilla/buglist.cgi?product=Fedora+Core&amp;component=libvirt&amp;bug_status=NEW&amp;bug_status=ASSIGNED&amp;bug_status=REOPENED&amp;bug_status=MODIFIED&amp;short_desc_type=allwordssubstr&amp;short_desc=&amp;long_desc_type=allwordssubstr">Open bugs</a></li><li><a href="http://virt-manager.et.redhat.com/">virt-manager</a></li><li><a href="http://search.cpan.org/~danberr/Sys-Virt-0.1.0/">Perl bindings</a></li><li><a href="http://libvirt.org/ocaml/">OCaml bindings</a></li><li><a href="http://libvirt.org/ruby/">Ruby bindings</a></li><li><a href="http://www.cl.cam.ac.uk/Research/SRG/netos/xen/index.html">Xen project</a></li><li><form action="../search.php" enctype="application/x-www-form-urlencoded" method="get"><input name="query" type="text" size="12" value="Search..." /><input name="submit" type="submit" value="Go" /></form></li><li><a href="http://xmlsoft.org/"><img src="../Libxml2-Logo-90x34.gif" alt="Made with Libxml2 Logo" /></a></li></ul><p class="credits">Graphics and design by <a href="mail:dfong@redhat.com">Diana Fong</a></p></div></div><div id="bottom"><p class="p1"></p></div></div></body></html>
Index: docs/examples/suspend.c
===================================================================
RCS file: /data/cvs/libvirt/docs/examples/suspend.c,v
retrieving revision 1.4
diff -u -r1.4 suspend.c
--- docs/examples/suspend.c	5 Feb 2008 19:27:37 -0000	1.4
+++ docs/examples/suspend.c	14 Mar 2008 10:06:59 -0000
@@ -25,7 +25,7 @@
  */
 static int
 checkDomainState(virDomainPtr dom) {
-    virDomainInfo info;        /* the informations being fetched */
+    virDomainInfo info;        /* the information being fetched */
     int ret;
 
     ret = virDomainGetInfo(dom, &info);
@@ -39,7 +39,7 @@
  * SuspendAndResumeDomain:
  * @id: the id of the domain
  *
- * extract the domain 0 informations
+ * extract the domain 0 information
  */
 static void
 SuspendAndResumeDomain(int id) {
Index: docs/html/libvirt-libvirt.html
===================================================================
RCS file: /data/cvs/libvirt/docs/html/libvirt-libvirt.html,v
retrieving revision 1.35
diff -u -r1.35 libvirt-libvirt.html
--- docs/html/libvirt-libvirt.html	3 Mar 2008 06:18:06 -0000	1.35
+++ docs/html/libvirt-libvirt.html	14 Mar 2008 10:07:08 -0000
@@ -261,8 +261,8 @@
     <a name="VIR_DOMAIN_CRASHED" id="VIR_DOMAIN_CRASHED">VIR_DOMAIN_CRASHED</a> = 6 : the domain is crashed
 }
 </pre><h3>Enum <a name="virDomainXMLFlags" id="virDomainXMLFlags">virDomainXMLFlags</a></h3><pre class="programlisting">Enum virDomainXMLFlags {
-    <a name="VIR_DOMAIN_XML_SECURE" id="VIR_DOMAIN_XML_SECURE">VIR_DOMAIN_XML_SECURE</a> = 1 : dump security sensitive informations too
-    <a name="VIR_DOMAIN_XML_INACTIVE" id="VIR_DOMAIN_XML_INACTIVE">VIR_DOMAIN_XML_INACTIVE</a> = 2 : dump inactive domain informations
+    <a name="VIR_DOMAIN_XML_SECURE" id="VIR_DOMAIN_XML_SECURE">VIR_DOMAIN_XML_SECURE</a> = 1 : dump security sensitive information too
+    <a name="VIR_DOMAIN_XML_INACTIVE" id="VIR_DOMAIN_XML_INACTIVE">VIR_DOMAIN_XML_INACTIVE</a> = 2 : dump inactive domain information
 }
 </pre><h3><a name="virNetwork" id="virNetwork">Structure virNetwork</a></h3><pre class="programlisting">Structure virNetwork<br />struct _virNetwork {
 The content of this structure is not made public by the API.
Index: include/libvirt/libvirt.h.in
===================================================================
RCS file: /data/cvs/libvirt/include/libvirt/libvirt.h.in,v
retrieving revision 1.44
diff -u -r1.44 libvirt.h.in
--- include/libvirt/libvirt.h.in	3 Mar 2008 06:18:06 -0000	1.44
+++ include/libvirt/libvirt.h.in	14 Mar 2008 10:07:11 -0000
@@ -71,7 +71,7 @@
  * virDomainInfoPtr:
  *
  * a virDomainInfo is a structure filled by virDomainGetInfo() and extracting
- * runtime informations for a given active Domain
+ * runtime information for a given active Domain
  */
 
 typedef struct _virDomainInfo virDomainInfo;
@@ -106,7 +106,7 @@
  * virNodeInfoPtr:
  *
  * a virNodeInfo is a structure filled by virNodeGetInfo() and providing
- * the informations for the Node.
+ * the information for the Node.
  */
 
 typedef struct _virNodeInfo virNodeInfo;
@@ -469,7 +469,7 @@
 						 int flags);
 
 /*
- * Domain runtime informations
+ * Domain runtime information
  */
 int			virDomainGetInfo	(virDomainPtr domain,
 						 virDomainInfoPtr info);
@@ -507,8 +507,8 @@
  */
 
 typedef enum {
-    VIR_DOMAIN_XML_SECURE = 1, /* dump security sensitive informations too */
-    VIR_DOMAIN_XML_INACTIVE = 2/* dump inactive domain informations */
+    VIR_DOMAIN_XML_SECURE = 1, /* dump security sensitive information too */
+    VIR_DOMAIN_XML_INACTIVE = 2/* dump inactive domain information */
 } virDomainXMLFlags;
 
 char *			virDomainGetXMLDesc	(virDomainPtr domain,
@@ -744,7 +744,7 @@
 int			virNetworkFree		(virNetworkPtr network);
 
 /*
- * Network informations
+ * Network information
  */
 const char*		virNetworkGetName	(virNetworkPtr network);
 int			virNetworkGetUUID	(virNetworkPtr network,
Index: proxy/libvirt_proxy.c
===================================================================
RCS file: /data/cvs/libvirt/proxy/libvirt_proxy.c,v
retrieving revision 1.27
diff -u -r1.27 libvirt_proxy.c
--- proxy/libvirt_proxy.c	22 Feb 2008 15:53:13 -0000	1.27
+++ proxy/libvirt_proxy.c	14 Mar 2008 10:07:13 -0000
@@ -571,7 +571,7 @@
 	        goto comm_error;
 
 	    /*
-	     * Hum, could we expect those informations to be unmutable and
+	     * Hum, could we expect those information to be unmutable and
 	     * cache them ? Since it's probably an unfrequent call better
 	     * not make assumption and do the xend RPC each call.
 	     */
@@ -763,7 +763,7 @@
 /**
  * usage:
  *
- * dump on stdout informations about the program
+ * dump on stdout information about the program
  */
 static void
 usage(const char *progname) {
Index: python/libvir.py
===================================================================
RCS file: /data/cvs/libvirt/python/libvir.py,v
retrieving revision 1.7
diff -u -r1.7 libvir.py
--- python/libvir.py	5 Dec 2007 19:09:23 -0000	1.7
+++ python/libvir.py	14 Mar 2008 10:07:13 -0000
@@ -85,7 +85,7 @@
 def registerErrorHandler(f, ctx):
     """Register a Python written function to for error reporting.
        The function is called back as f(ctx, error), with error
-       being a list of informations about the error being raised.
+       being a list of information about the error being raised.
        Returns 1 in case of success."""
     return libvirtmod.virRegisterErrorHandler(f,ctx)
 
Index: python/libvirt-python-api.xml
===================================================================
RCS file: /data/cvs/libvirt/python/libvirt-python-api.xml,v
retrieving revision 1.11
diff -u -r1.11 libvirt-python-api.xml
--- python/libvirt-python-api.xml	29 Feb 2008 12:53:11 -0000	1.11
+++ python/libvirt-python-api.xml	14 Mar 2008 10:07:13 -0000
@@ -34,13 +34,13 @@
       <arg name='uuid' type='const unsigned char *' info='the UUID string for the network, must be 16 bytes'/>
     </function>
     <function name='virDomainGetInfo' file='python'>
-      <info>Extract informations about a domain. Note that if the connection used to get the domain is limited only a partial set of the informations can be extracted.</info>
-      <return type='int *' info='the list of informations or None in case of error'/>
+      <info>Extract information about a domain. Note that if the connection used to get the domain is limited only a partial set of the information can be extracted.</info>
+      <return type='int *' info='the list of information or None in case of error'/>
       <arg name='domain' type='virDomainPtr' info='a domain object'/>
     </function>
     <function name='virNodeGetInfo' file='python'>
-      <info>Extract hardware informations about the Node.</info>
-      <return type='int *' info='the list of informations or None in case of error'/>
+      <info>Extract hardware information about the Node.</info>
+      <return type='int *' info='the list of information or None in case of error'/>
       <arg name='conn' type='virConnectPtr' info='pointer to the hypervisor connection'/>
     </function>
     <function name='virDomainGetUUID' file='python'>
Index: python/tests/node.py
===================================================================
RCS file: /data/cvs/libvirt/python/tests/node.py,v
retrieving revision 1.1
diff -u -r1.1 node.py
--- python/tests/node.py	29 Mar 2006 13:33:37 -0000	1.1
+++ python/tests/node.py	14 Mar 2008 10:07:13 -0000
@@ -15,14 +15,14 @@
 try:
     (model, memory, cpus, mhz, nodes, socket, cores, threads) = conn.getInfo()
 except:
-    print 'Failed to extract the current node informations'
+    print 'Failed to extract the current node information'
     sys.exit(1)
 
 print "Xen running on %d %s processors at %d MHz, %d MBytes of memory" % (
        cpus, model, mhz, memory)
 
 if cpus > nodes * socket * cores * threads:
-    print "Erroneous CPU informations"
+    print "Erroneous CPU information"
     sys.exit(1)
 
 if cpus < nodes * socket * cores * threads:
Index: src/xen_internal.c
===================================================================
RCS file: /data/cvs/libvirt/src/xen_internal.c,v
retrieving revision 1.114
diff -u -r1.114 xen_internal.c
--- src/xen_internal.c	27 Feb 2008 10:37:19 -0000	1.114
+++ src/xen_internal.c	14 Mar 2008 10:07:19 -0000
@@ -397,28 +397,28 @@
 typedef struct xen_v0_domainop xen_v0_domainop;
 
 /*
- * The informations for a destroydomain system hypercall
+ * The information for a destroydomain system hypercall
  */
 #define XEN_V0_OP_DESTROYDOMAIN	9
 #define XEN_V1_OP_DESTROYDOMAIN	9
 #define XEN_V2_OP_DESTROYDOMAIN	2
 
 /*
- * The informations for a pausedomain system hypercall
+ * The information for a pausedomain system hypercall
  */
 #define XEN_V0_OP_PAUSEDOMAIN	10
 #define XEN_V1_OP_PAUSEDOMAIN	10
 #define XEN_V2_OP_PAUSEDOMAIN	3
 
 /*
- * The informations for an unpausedomain system hypercall
+ * The information for an unpausedomain system hypercall
  */
 #define XEN_V0_OP_UNPAUSEDOMAIN	11
 #define XEN_V1_OP_UNPAUSEDOMAIN	11
 #define XEN_V2_OP_UNPAUSEDOMAIN	4
 
 /*
- * The informations for an setmaxmem system hypercall
+ * The information for an setmaxmem system hypercall
  */
 #define XEN_V0_OP_SETMAXMEM	28
 #define XEN_V1_OP_SETMAXMEM	28
@@ -442,7 +442,7 @@
 typedef struct xen_v2d5_setmaxmem xen_v2d5_setmaxmem;
 
 /*
- * The informations for an setmaxvcpu system hypercall
+ * The information for an setmaxvcpu system hypercall
  */
 #define XEN_V0_OP_SETMAXVCPU	41
 #define XEN_V1_OP_SETMAXVCPU	41
@@ -461,7 +461,7 @@
 typedef struct xen_v2_setmaxvcpu xen_v2_setmaxvcpu;
 
 /*
- * The informations for an setvcpumap system hypercall
+ * The information for an setvcpumap system hypercall
  * Note that between 1 and 2 the limitation to 64 physical CPU was lifted
  * hence the difference in structures
  */
@@ -509,7 +509,7 @@
 typedef struct xen_v2d5_setvcpumap xen_v2d5_setvcpumap;
 
 /*
- * The informations for an vcpuinfo system hypercall
+ * The information for an vcpuinfo system hypercall
  */
 #define XEN_V0_OP_GETVCPUINFO   43
 #define XEN_V1_OP_GETVCPUINFO	43
@@ -980,7 +980,7 @@
  * @maxids: maximum number of domains to list
  * @dominfos: output structures
  *
- * Do a low level hypercall to list existing domains informations
+ * Do a low level hypercall to list existing domains information
  *
  * Returns the number of domains or -1 in case of failure
  */

Index: docs/examples/info1.c
===================================================================
RCS file: /data/cvs/libvirt/docs/examples/info1.c,v
retrieving revision 1.4
diff -u -r1.4 info1.c
--- docs/examples/info1.c	6 Mar 2007 22:59:03 -0000	1.4
+++ docs/examples/info1.c	14 Mar 2008 10:06:59 -0000
@@ -1,8 +1,8 @@
 /**
  * section: Informations
  * synopsis: Extract informations about Xen domain 0
  * purpose: Demonstrate the basic use of the library to connect to the
  *          hypervisor and extract domain informations.
  * usage: info1
  * test: info1
  * author: Daniel Veillard
@@ -16,13 +16,13 @@
  * getDomainInfo:
  * @id: the id of the domain
  *
  * extract the domain 0 informations
  */
 static void
 getDomainInfo(int id) {
     virConnectPtr conn = NULL; /* the hypervisor connection */
     virDomainPtr dom = NULL;   /* the domain being checked */
-    virDomainInfo info;        /* the informations being fetched */
+    virDomainInfo info;        /* the information being fetched */
     int ret;
 
     /* NULL means connect to local Xen hypervisor */
@@ -39,10 +39,10 @@
 	goto error;
     }
 
-    /* Get the informations */
+    /* Get the information */
     ret = virDomainGetInfo(dom, &info);
     if (ret < 0) {
-        fprintf(stderr, "Failed to get informations for Domain %d\n", id);
+        fprintf(stderr, "Failed to get information for Domain %d\n", id);
 	goto error;
     }
 
@@ -1,8 +1,8 @@
 /**
  * section: Informations
- * synopsis: Extract informations about Xen domain 0
+ * synopsis: Extract information about Xen domain 0
  * purpose: Demonstrate the basic use of the library to connect to the
@@ -1,8 +1,8 @@
  * purpose: Demonstrate the basic use of the library to connect to the
- *          hypervisor and extract domain informations.
+ *          hypervisor and extract domain information.
  * usage: info1
  * test: info1
@@ -16,13 +16,13 @@
  * @id: the id of the domain
  *
- * extract the domain 0 informations
+ * extract the domain 0 information
  */
 static void
Index: include/libvirt/libvirt.h
===================================================================
RCS file: /data/cvs/libvirt/include/libvirt/libvirt.h,v
retrieving revision 1.68
diff -u -r1.68 libvirt.h
--- include/libvirt/libvirt.h	3 Mar 2008 14:42:37 -0000	1.68
+++ include/libvirt/libvirt.h	14 Mar 2008 10:07:10 -0000
@@ -71,7 +71,7 @@
  * virDomainInfoPtr:
  *
  * a virDomainInfo is a structure filled by virDomainGetInfo() and extracting
  * runtime informations for a given active Domain
  */
 
 typedef struct _virDomainInfo virDomainInfo;
@@ -106,7 +106,7 @@
  * virNodeInfoPtr:
  *
  * a virNodeInfo is a structure filled by virNodeGetInfo() and providing
  * the informations for the Node.
  */
 
 typedef struct _virNodeInfo virNodeInfo;
@@ -469,7 +469,7 @@
 						 int flags);
 
 /*
  * Domain runtime informations
  */
 int			virDomainGetInfo	(virDomainPtr domain,
 						 virDomainInfoPtr info);
@@ -507,8 +507,8 @@
  */
 
 typedef enum {
-    VIR_DOMAIN_XML_SECURE = 1, /* dump security sensitive informations too */
-    VIR_DOMAIN_XML_INACTIVE = 2/* dump inactive domain informations */
+    VIR_DOMAIN_XML_SECURE = 1, /* dump security sensitive information too */
+    VIR_DOMAIN_XML_INACTIVE = 2/* dump inactive domain information */
 } virDomainXMLFlags;
 
 char *			virDomainGetXMLDesc	(virDomainPtr domain,
@@ -744,7 +744,7 @@
 int			virNetworkFree		(virNetworkPtr network);
 
 /*
- * Network informations
+ * Network information
  */
 const char*		virNetworkGetName	(virNetworkPtr network);
 int			virNetworkGetUUID	(virNetworkPtr network,
@@ -71,7 +71,7 @@
  *
  * a virDomainInfo is a structure filled by virDomainGetInfo() and extracting
- * runtime informations for a given active Domain
+ * runtime information for a given active Domain
  */
 
@@ -106,7 +106,7 @@
  *
  * a virNodeInfo is a structure filled by virNodeGetInfo() and providing
- * the informations for the Node.
+ * the information for the Node.
  */
 
@@ -469,7 +469,7 @@
 
 /*
- * Domain runtime informations
+ * Domain runtime information
  */
 int			virDomainGetInfo	(virDomainPtr domain,